<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sr_RS">
<context>
    <name>ConfigureDialog</name>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="14"/>
        <source>Runner Settings</source>
        <translation>Поставке покретача</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="20"/>
        <source>Appearance</source>
        <translation>Изглед</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="26"/>
        <source>Positioning:</source>
        <translation>Позиција:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="36"/>
        <source>Top margin</source>
        <translation>Горња маргина</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="43"/>
        <source> px</source>
        <translation> пкс</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="50"/>
        <source>Width:</source>
        <translation>Ширина:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="57"/>
        <source>With multiple screens, if the window is shown on the focused screen,
this value is only for the smallest screen. The minimum width is 400 px.</source>
        <translation>Са више екрана, ако се прозор приказује на фокусираном екрану, ова вредност је само за најмањи екран. Минимална ширина је 400 пиксела.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="61"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="71"/>
        <source>Show on:</source>
        <translation>Прикажи на:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="108"/>
        <source>Show history first</source>
        <translation>Прво прикажи историју</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="101"/>
        <source>Store/show history</source>
        <translation>Сачувај/прикажи историју</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="81"/>
        <source>&lt;b&gt;Note&lt;/b&gt;: The size of top-level widgets are constrained to 2/3 of the desktop&apos;s height and width.</source>
        <translation>&lt;b&gt;Напомена&lt;/b&gt;: Величина виџета највишег нивоа је ограничена на 2/3 висине и ширине радне површине.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="84"/>
        <source>Show list with:</source>
        <translation>Прикажи листе са:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="91"/>
        <source> item(s)</source>
        <translation> ставка(е)</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="115"/>
        <source>Clear input on launching</source>
        <translation>Очисти унос приликом покретања</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.ui" line="132"/>
        <source>Shortcut:</source>
        <translation>Пречица:</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="61"/>
        <source>Top edge of the screen</source>
        <translation>Горња ивица екрана</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="62"/>
        <source>Center of the screen</source>
        <translation>Центар екрана</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="71"/>
        <source>On Wayland, the shortcut has to be added
in the compositor settings for &apos;lxqt-runner&apos;.</source>
        <translation>На вејленду, пречица мора бити додата у поставкама композитора за „lxqt-runner“.</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="83"/>
        <source>Focused screen</source>
        <translation>Екран у фокусу</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="87"/>
        <source>Always on screen %1</source>
        <translation>Увек на екрану %1</translation>
    </message>
    <message>
        <location filename="../configuredialog/configuredialog.cpp" line="96"/>
        <source>Reset</source>
        <translation>Ресетуј</translation>
    </message>
</context>
<context>
    <name>Dialog</name>
    <message>
        <location filename="../dialog.ui" line="26"/>
        <source>Application launcher </source>
        <translation>Покретач програма </translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="109"/>
        <source>Configure</source>
        <translation>Конфигуриши</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="113"/>
        <source>Clear History</source>
        <translation>Обриши историју</translation>
    </message>
    <message>
        <location filename="../dialog.cpp" line="523"/>
        <source>Show/hide runner dialog</source>
        <translation>Прикажи/сакриј дијалог покретача</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../providers.cpp" line="445"/>
        <source>History</source>
        <translation>Историјат</translation>
    </message>
    <message>
        <location filename="../providers.cpp" line="846"/>
        <source>Copy calculation result to clipboard</source>
        <translation>Копирај резултат израчунавања у клипборд</translation>
    </message>
</context>
</TS>
